@@ -6,11 +6,12 @@ from labstep.generic.entity.repository import entityRepository
 
 
 class ExperimentProtocolRepository:
-    def exportExperimentProtocol(self, experimentProtocol, rootPath):
+    def exportExperimentProtocol(self, experimentProtocol, rootPath, folderName):
 
         experimentProtocol.update()
 
-        expDir = entityRepository.exportEntity(experimentProtocol, rootPath)
+        expDir = entityRepository.exportEntity(
+            experimentProtocol, rootPath, folderName)
 
         # save materials
         materialsDir = expDir.joinpath('materials')
