@@ -25,7 +25,7 @@ class ProtocolTimer(Entity):
 
         Returns
         -------
-        :class:`~labstep.protocol.ProtocolTimer`
+        :class:`~labstep.entities.protocolTimer.model.ProtocolTimer`
             An object representing the edited Protocol Timer.
 
         Example
