@@ -258,6 +258,29 @@ class User(Entity):
 
         return workspaceRepository.getWorkspace(self, workspace_id)
 
+    def getOrganization(self):
+        """
+        Returns the organization the user is part of.
+
+        Returns
+        -------
+        :class:`~labstep.entities.organization.model.Organization`
+            An object representing an Organization on Labstep.
+
+        Example
+        -------
+        ::
+
+            organization = user.getOrganization()
+        """
+        from labstep.entities.organization.repository import organizationRepository
+
+        if len(self.user_organizations) > 0:
+
+            organizationId = self.user_organizations[0]['organization']['id']
+
+            return organizationRepository.getOrganization(self, organizationId)
+
     def getFile(self, file_id):
         """
         Retrieve a specific Labstep File.
@@ -307,6 +330,7 @@ class User(Entity):
         return deviceRepository.getDevice(self, device_id)
 
     # getMany()
+
     def getExperiments(
         self,
         count=100,
@@ -728,7 +752,7 @@ class User(Entity):
 
         return protocolRepository.newProtocol(self, name, extraParams=extraParams)
 
-    def newResource(self, name, extraParams={}):
+    def newResource(self, name, resource_category_id=None, extraParams={}):
         """
         Create a new Labstep Resource.
 
@@ -737,6 +761,9 @@ class User(Entity):
         name (str)
             Give your Resource a name.
 
+        resource_category_id (int)
+            ID of the resource category of the new resource
+
         Returns
         -------
         :class:`~labstep.entities.resource.model.Resource`
@@ -750,7 +777,7 @@ class User(Entity):
         """
         from labstep.entities.resource.repository import resourceRepository
 
-        return resourceRepository.newResource(self, name, extraParams=extraParams)
+        return resourceRepository.newResource(self, name, resource_category_id=resource_category_id, extraParams=extraParams)
 
     def newResourceCategory(self, name, extraParams={}):
         """
