@@ -87,12 +87,15 @@ class EntityRepository:
         entity.__init__(json.loads(response.content), entity.__user__)
         return entity
 
-    def exportEntity(self, entity, rootPath):
+    def exportEntity(self, entity, rootPath, folderName=None):
 
         from labstep.entities.file.model import File
 
-        entityDir = Path(rootPath).joinpath(
-            f'{entity.id}')
+        if folderName is None:
+            folderName = f'{entity.id} - {entity.name}' if hasattr(
+                entity, 'name') else f'{entity.id}'
+
+        entityDir = Path(rootPath).joinpath(folderName)
         entityDir.mkdir(parents=True, exist_ok=True)
         infoFile = entityDir.joinpath('entity.json')
 
